<?php
/**
 * Plugin Name: Random Image
 * Description: Random Image Elementor plugin is a simple tool that allows you to display random images on your website. It's easy to use and customizable.
 * Plugin URI:  https://bestwpdeveloper.com/random-image
 * Version:     1.0
 * Author:      20script
 * Author URI:  https://www.20script.ir
 * Text Domain: bwdrmx-random-imagetd
 * Elementor tested up to: 3.0.0
 * Elementor Pro tested up to: 3.7.3
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
require_once ( plugin_dir_path(__FILE__) ) . '/includes/bwdrmx-plugin-activition.php';
final class bwdrmx_randomImage{

	const VERSION = '1.3';

	const MINIMUM_ELEMENTOR_VERSION = '3.0.0';

	const MINIMUM_PHP_VERSION = '7.0';

	public function __construct() {
		// Load translation
		add_action( 'bwdrmx_init', array( $this, 'bwdrmx_loaded_textdomain' ) );
		// bwdrmx_init Plugin
		add_action( 'plugins_loaded', array( $this, 'bwdrmx_init' ) );
	}

	public function bwdrmx_loaded_textdomain() {
		load_plugin_textdomain( 'bwdrmx-random-imagetd' );
	}

	public function bwdrmx_init() {
		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', 'bwdrmx_randomimage_addon_failed_load' );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', array( $this, 'bwdrmx_admin_notice_minimum_elementor_version' ) );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', array( $this, 'bwdrmx_admin_notice_minimum_php_version' ) );
			return;
		}

		// Once we get here, We have passed all validation checks so we can safely include our plugin
		require_once( 'bwdrmx-random-image-boots.php' );
	}

	public function bwdrmx_admin_notice_minimum_elementor_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'bwdrmx-random-imagetd' ),
			'<strong>' . esc_html__( 'Random Image', 'bwdrmx-random-imagetd' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'bwdrmx-random-imagetd' ) . '</strong>',
			self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>' . esc_html__('%1$s', 'bwdrmx-random-imagetd') . '</p></div>', $message );
	}

	public function bwdrmx_admin_notice_minimum_php_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'bwdrmx-random-imagetd' ),
			'<strong>' . esc_html__( 'Random Image', 'bwdrmx-random-imagetd' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'bwdrmx-random-imagetd' ) . '</strong>',
			self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>' . esc_html__('%1$s', 'bwdrmx-random-imagetd') . '</p></div>', $message );
	}
}

// Instantiate randomImage.
new bwdrmx_randomImage();
remove_action( 'shutdown', 'wp_ob_end_flush_all', 1 );